import React, { useState } from 'react'
import { useTranslation } from 'react-i18next'

import { appTheme, appTimezone, appVersion, appInst } from 'appConfig'

export const Debug = () => {
  const [apiHealth, setApiHealth] = useState('not yet')
  const [didContactApi, setDidContactApi] = useState(false)
  const { i18n } = useTranslation(['common'])

  if (!didContactApi) {
    setDidContactApi(true)
    fetch('http://localhost:3000/api/health/')
      .then((res) => res.text())
      .then((result) => {
        if (result === 'OK') {
          setApiHealth('yes')
        } else {
          setApiHealth(result)
        }
      })
      // eslint-disable-next-line @typescript-eslint/no-unused-vars
      .catch((error) => {
        setApiHealth('error')
      })
  }

  const d = [
    ['NODE_ENV', process.env.NODE_ENV],
    ['Version', appVersion],
    ['Timezone', appTimezone],
    ['Language', i18n.language],
    ['Theme', appTheme],
    ['Institution', appInst],
    ['API reachable?', apiHealth],
  ]
  return (
    <table>
      <thead>
        <strong>Debug</strong>
      </thead>
      <tbody>
        {d.map(([key, value]) => (
          <tr>
            <td>{key}</td>
            <td>{value}</td>
          </tr>
        ))}
      </tbody>
    </table>
  )
}

export default Debug
