import React from 'react'
import { Helmet } from 'react-helmet'
import { useTranslation } from 'react-i18next'

import styled from 'styled-components/macro'

const StyledPage = styled.main`
  display: block;
  justify-content: space-between;
  margin: 0 auto;
  max-width: ${(props) => props.theme.appMaxWidth};
  padding: ${(props) =>
    `0.5rem ${props.theme.horizontalPadding} 1rem ${props.theme.horizontalPadding}`};
`

const StyledPageHeader = styled.h2`
  color: ${({ theme }) => theme.page.headerColor};
  font-size: 3rem;
  font-weight: bold;
  margin: 0rem ${({ theme }) => theme.page.horizontalPadding} 0
    ${({ theme }) => theme.page.horizontalPadding};
`

interface IPage {
  children: React.ReactNode
  header?: string
}

export default function Page(props: IPage) {
  const { header, children } = props
  const { i18n, t } = useTranslation()
  const appTitle = t('common:header:applicationTitle')

  return (
    <>
      <Helmet titleTemplate={`%s - ${appTitle}`} defaultTitle={appTitle}>
        <html lang={i18n.language} />
        <title>{header}</title>
      </Helmet>
      <StyledPage>
        <StyledPageHeader>{header}</StyledPageHeader>
        {children}
      </StyledPage>
    </>
  )
}

Page.defaultProps = {
  header: null,
}
