import React from 'react'
import { Link } from 'react-router-dom'
import styled from 'styled-components/macro'
import { useTranslation } from 'react-i18next'
import LogoBar from '../../components/logobars/LogoBar'
import LanguageSelector from '../../components/languageselector'

const MainWrapper = styled.div`
  color: ${({ theme }) => theme.page.headerColor};
  background-color: ${({ theme }) => theme.page.headerBackgroundColor};
`

const Main = styled.div`
  display: flex;
  justify-content: space-between;
  margin: 0 auto;
  max-width: ${(props) => props.theme.appMaxWidth};
  padding: ${(props) =>
    `0.5rem ${props.theme.horizontalPadding} 1rem ${props.theme.horizontalPadding}`};
`

const Menu = styled.ul`
  list-style-type: none;
`

const MenuItem = styled.div`
  font-size: 1rem;
  display: inline;
`

const TitleBox = styled.div`
  display: flex;
  flex-direction: column;
  padding-left: 3rem;
`

const Title = styled.div`
  font-size: 2rem;
`

const Description = styled.div`
  font-size: 1rem;
`

const Header = () => {
  const { t } = useTranslation('common')

  return (
    <header>
      <LogoBar />
      <MainWrapper>
        <Main>
          <TitleBox>
            <Link to="/">
              <Title>{t('header.applicationTitle')}</Title>
            </Link>
            <Description>{t('header.applicationDescription')}</Description>
          </TitleBox>
          <Menu>
            <MenuItem>
              <LanguageSelector />
            </MenuItem>
          </Menu>
        </Main>
      </MainWrapper>
    </header>
  )
}

export default Header
