import React from 'react'
import { useTranslation } from 'react-i18next'

import { StyledInput } from 'components/form/input'
import DateInput from 'components/dateinput'
import Button from 'components/button'
import Page from 'components/page'
import { useForm, Controller, SubmitHandler } from 'react-hook-form'
import format from 'date-fns/format'
import { postJsonOpts } from 'utils'

type RegisterFormData = {
  first_name: string
  last_name: string
  date_of_birth: Date
}

export default function Register() {
  const { t } = useTranslation(['common'])

  const submit: SubmitHandler<RegisterFormData> = (data) => {
    const payload = {
      first_name: data.first_name,
      last_name: data.last_name,
      date_of_birth: format(data.date_of_birth, 'yyyy-MM-dd'),
    }
    console.log('submitting', JSON.stringify(payload))
    fetch('http://localhost:3000/api/ui/v1/register/', postJsonOpts(payload))
      .then((res) => res.text())
      .then((result) => {
        console.log('result', result)
      })
      .catch((error) => {
        console.log('error', error)
      })
  }

  const {
    register,
    control,
    handleSubmit,
    // setValue,
    // formState: { errors },
  } = useForm<RegisterFormData>()
  const onSubmit = handleSubmit(submit)

  return (
    <Page header="Register as a guest">
      <form onSubmit={onSubmit}>
        <StyledInput
          {...register(`first_name`)}
          placeholder={t('common:firstName')}
        />
        <StyledInput
          {...register(`last_name`)}
          placeholder={t('common:lastName')}
        />
        <Controller
          name="date_of_birth"
          control={control}
          render={({ field }) => (
            <DateInput
              customInput={<StyledInput />}
              placeholderText={t('common:dateOfBirth')}
              onChange={(date) => field.onChange(date)}
              selected={field.value}
            />
          )}
        />
        {/* <Select name="gender" options={['female', 'male', 'other']} />
        <Fnr name={t('common:fnr')} /> */}
        <Button as="button" type="submit">
          Submit
        </Button>
      </form>
    </Page>
  )
}
